@@ -7,8 +7,6 @@ from django.shortcuts import redirect, get_object_or_404
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
 
-import reversion
-
 from .models import MenuItem
 from ..settings import ADMIN_MEDIA_PREFIX
 
@@ -18,7 +16,7 @@ class MenuItemInline(admin.TabularInline):
     model = MenuItem
 
 
-class MenuItemAdmin(reversion.VersionAdmin):
+class MenuItemAdmin(admin.ModelAdmin):
 
     fields = (('lang', 'menuitem_name'), 'url')
     list_display = ('menuitem_name', 'lang', 'url', 'move', 'position')
